#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#       sqlviewer.py
#       
#       Copyright 2013 Recursos Python - www.recursospython.com
#       

import sys

from PyQt4.QtCore import QStringList, QString
from PyQt4.QtGui import (QAbstractItemView, QApplication, QFileDialog,
                         QMainWindow, QTabWidget)

from database import DataBase
from dbtablewidget import DBTableWidget


class Window(QMainWindow):
    
    def __init__(self, dbname):
        QMainWindow.__init__(self)
        
        # Establecer título y tamaño
        self.setWindowTitle("Visor de base de datos SQLite")
        self.resize(800, 450)
        
        self.tab_widget = QTabWidget(self)
        self.setCentralWidget(self.tab_widget)
        
        # Abrir la base de datos
        self.db = DataBase()
        self.db.open(dbname)
        
        # Añadir una pestaña por cada tabla
        for table in self.db.get_tables():
            table_name = table[1]
            table_info = self.db.get_table_info(table_name)
            table_widget = DBTableWidget(self.tab_widget)
            table_widget.setAlternatingRowColors(True)
            table_widget.setShowGrid(True)
            table_widget.setColumnCount(0)
            table_widget.setRowCount(0)
            table_widget.setHorizontalScrollMode(
                QAbstractItemView.ScrollPerPixel)
            
            string_list = QStringList()
            
            database_table_name = table_name
            database_table_column_count = len(table_info)
            database_table_columns = {}
            database_table_items = []
            
            table_widget.setColumnCount(database_table_column_count)
            
            # Obtener y añadir columnas
            for column in table_info:
                string_list.append(QString(column[1]))
                database_table_columns[column[0]] = column[1]
            
            table_widget.setHorizontalHeaderLabels(string_list)
            
            # Obtener y añadir filas
            for items in self.db.get_table_items(table_name):
                table_widget.add_row(items)
                database_table_items.append([item for item in items])
            
            self.tab_widget.addTab(table_widget, table_name)
        
        self.db.close()


if __name__ == "__main__":
    app = QApplication([])
    
    # Tomar un archivo de la línea de comandos o abrir el explorador
    if len(sys.argv) > 1:
        filename = sys.argv[1]
    else:
        filename = QFileDialog.getOpenFileName(
            None, filter="Archivos SQLite (*.db *.sqlite *.sqlite3);;"
                         "Todos los archivos (*.*)")
    
    window = Window(filename if isinstance(filename, basestring) else
                    unicode(filename))
    window.show()
    sys.exit(app.exec_())
